%% Low and High Frequency Signals


%% Specify signals
N = 1000;
T = 10;
t = linspace(0,T,N);
t = t(:);

% Slow ramp up and down
idx1 = t<2;
idx2 = t>=2 & t<=8;
idx3 = t>8;
r = zeros(N,1);
r(idx1) = 1-cos(pi*t(idx1)/2);
r(idx2) = 2;
r(idx3) = 1+cos( pi*(t(idx3)-8)/2 );

% Reset random number generator
% This allows the results\ for the random signal to be repeatable.
stream = RandStream.getGlobalStream;
reset(stream);

% Random noise
n = 0.5*randn(N,1);


%% Frequency Components: Low Frequency Signal

% The Discrete Fourier Transform is applied on the sampled data.
[A,~,w] = cosDFT(r,t);
Ncos = numel(A);
ww=[w w w]'; 
AA = [zeros(Ncos,1) A zeros(Ncos,1)]';

figure(1);
clf

subplot(2,1,1)
plot(t,r,'b')
grid on;
ylabel('r');
xlabel('Time, sec');
ylim([0 2.5]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

subplot(2,1,2)
plot(ww,AA,'b',w,A,'bo');
ylabel('Amplitudes');
xlabel('Frequency \omega_k, rad/sec');
grid on;
xlim([0 15]);
set(gca, 'LooseInset', get(gca, 'TightInset'));


% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(1)
    garyfyFigure
    myprint(1,'LFsig')
end

%% Frequency Components: High Frequency Signal

% The Discrete Fourier Transform is applied on the sampled data.
[A,~,w] = cosDFT(n,t);
Ncos = numel(A);
ww=[w w w]'; 
AA = [zeros(Ncos,1) A zeros(Ncos,1)]';

figure(2);
clf

subplot(2,1,1)
plot(t,n,'b')
grid on;
ylabel('n');
xlabel('Time, sec');
ylim([-2 2]);
set(gca, 'LooseInset', get(gca, 'TightInset'));

subplot(2,1,2)
plot(ww,AA,'b',w,A,'bo');
ylabel('Amplitudes');
xlabel('Frequency \omega_k, rad/sec');
grid on;
xlim([0 ww(end)]);
set(gca, 'LooseInset', get(gca, 'TightInset'));


% Save Plots
if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    figure(2)
    garyfyFigure
    myprint(2,'HFsig')
end

